![GQLite logo](https://gqlite.org/assets/images/logo-88x88.png) graphcore
=========================================================================

`GraphCore` is part of the [GQLite project](https://gqlite.org) project, it provides base type for representing values, nodes and edges in a property graph.
